import { CommonModule } from '@angular/common';
import { Directive, Renderer2, ElementRef, NgModule } from '@angular/core';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxAnimatedGradientDirective {
    /**
     * @param {?} renderer
     * @param {?} el
     */
    constructor(renderer, el) {
        this.renderer = renderer;
        this.el = el;
        this.colors = [[62, 35, 255],
            [60, 255, 60],
            [255, 35, 98],
            [45, 175, 230],
            [255, 0, 255],
            [255, 128, 0]];
        this.step = 0;
        // color table indices for:
        // current color left
        // next color left
        // current color right
        // next color right
        this.colorIndices = [0, 1, 2, 3];
        // transition speed
        this.gradientSpeed = 0.002;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        console.log('NgxAnimatedGradientDirective init');
        setInterval((/**
         * @return {?}
         */
        () => {
            this.updateGradient();
        }), 10);
    }
    /**
     * @return {?}
     */
    updateGradient() {
        /** @type {?} */
        const c0_0 = this.colors[this.colorIndices[0]];
        /** @type {?} */
        const c0_1 = this.colors[this.colorIndices[1]];
        /** @type {?} */
        const c1_0 = this.colors[this.colorIndices[2]];
        /** @type {?} */
        const c1_1 = this.colors[this.colorIndices[3]];
        /** @type {?} */
        const istep = 1 - this.step;
        /** @type {?} */
        const r1 = Math.round(istep * c0_0[0] + this.step * c0_1[0]);
        /** @type {?} */
        const g1 = Math.round(istep * c0_0[1] + this.step * c0_1[1]);
        /** @type {?} */
        const b1 = Math.round(istep * c0_0[2] + this.step * c0_1[2]);
        /** @type {?} */
        const color1 = 'rgb(' + r1 + ',' + g1 + ',' + b1 + ')';
        /** @type {?} */
        const r2 = Math.round(istep * c1_0[0] + this.step * c1_1[0]);
        /** @type {?} */
        const g2 = Math.round(istep * c1_0[1] + this.step * c1_1[1]);
        /** @type {?} */
        const b2 = Math.round(istep * c1_0[2] + this.step * c1_1[2]);
        /** @type {?} */
        const color2 = 'rgb(' + r2 + ',' + g2 + ',' + b2 + ')';
        this.renderer.setStyle(this.el.nativeElement, 'background', '-webkit-gradient(linear, left top, right top, from(' + color1 + '), to(' + color2 + '))');
        this.renderer.setStyle(this.el.nativeElement, 'background', '-moz-linear-gradient(left, ' + color1 + ' 0%, ' + color2 + ' 100%)');
        // $('#gradient').css({
        //   background: `-webkit-gradient(linear, left top, right top, from(' + ${color1} + '), to(' + ${color2}  + '))`
        // }).css({
        //   background: `-moz-linear-gradient(left, ${color1}  0%, ${color2}   100%)`
        // });
        this.step += this.gradientSpeed;
        if (this.step >= 1) {
            this.step %= 1;
            this.colorIndices[0] = this.colorIndices[1];
            this.colorIndices[2] = this.colorIndices[3];
            // pick two new target color indices
            // do not pick the same as the current one
            this.colorIndices[1] = (this.colorIndices[1]
                + Math.floor(1 + Math.random() * (this.colors.length - 1))) % this.colors.length;
            this.colorIndices[3] = (this.colorIndices[3]
                + Math.floor(1 + Math.random() * (this.colors.length - 1))) % this.colors.length;
        }
    }
}
NgxAnimatedGradientDirective.decorators = [
    { type: Directive, args: [{
                selector: '[ngxAnimatedGradient]'
            },] },
];
/** @nocollapse */
NgxAnimatedGradientDirective.ctorParameters = () => [
    { type: Renderer2 },
    { type: ElementRef }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxAnimatedGradientModule {
}
NgxAnimatedGradientModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                exports: [NgxAnimatedGradientDirective],
                declarations: [NgxAnimatedGradientDirective]
            },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { NgxAnimatedGradientDirective, NgxAnimatedGradientModule };
//# sourceMappingURL=ngx-animated-gradient.js.map
